@@ -18,15 +18,9 @@
 from .service import (
     EmptyParams,
     EmptyResponse,
-    GetTonnageDryDockRequest,
-    GetTonnageDryDockResponse,
-    DryDockValue,
-    DryDockSummaryRequest,
-    DryDockSummaryResponse,
-    DryDockSummaryValue,
     GetDryDockStaysRequest,
     GetDryDockStaysResponse,
-    ShipyardStay,
+    HistoricalDryDockStay,
     GetDryDockRequest,
     DryDockTimeseriesGroup,
     DryDockTimeseriesRow,
@@ -38,15 +32,9 @@ from .service import (
 __all__ = (
     'EmptyParams',
     'EmptyResponse',
-    'GetTonnageDryDockRequest',
-    'GetTonnageDryDockResponse',
-    'DryDockValue',
-    'DryDockSummaryRequest',
-    'DryDockSummaryResponse',
-    'DryDockSummaryValue',
     'GetDryDockStaysRequest',
     'GetDryDockStaysResponse',
-    'ShipyardStay',
+    'HistoricalDryDockStay',
     'GetDryDockRequest',
     'DryDockTimeseriesGroup',
     'DryDockTimeseriesRow',
