@@ -178,7 +178,7 @@ class VesselServiceAsyncClient:
 
         Args:
             request (:class:`oceanbolt.com.vessels_v3.types.ListStoppageEventsRequest`):
-                The request object. VesselStoppageEvents
+                The request object.
 
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
