@@ -371,7 +371,7 @@ class VesselServiceClient(metaclass=VesselServiceClientMeta):
 
         Args:
             request (oceanbolt.com.vessels_v3.types.ListStoppageEventsRequest):
-                The request object. VesselStoppageEvents
+                The request object.
 
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
