@@ -42,7 +42,9 @@ class drydockCallTransformer(cst.CSTTransformer):
     CTRL_PARAMS: Tuple[str] = ('retry', 'timeout', 'metadata')
     METHOD_TO_PARAMS: Dict[str, Tuple[str]] = {
     'get_dry_dock_stays': ('imo', 'port_id', 'shipyard_id', 'unlocode', 'segment', 'sub_segment', 'start_date', 'end_date', 'latest_only', 'format_', 'sort', 'group_by', ),
-    'get_tonnage_dry_dock': ('segment', 'metric', 'absolute', 'format_', 'sort', ),
+    'get_dry_dock_timeseries': ('port_id', 'port_unlocode', 'shipyard_id', 'country_code', 'region_id', 'segment', 'sub_segment', 'group_by', 'exclude', 'format_', 'start_date', 'end_date', 'last_n_days', 'sort', 'display_date', ),
+    'get_dry_dock_vessels': ('port_id', 'port_unlocode', 'shipyard_id', 'country_code', 'region_id', 'segment', 'sub_segment', 'group_by', 'exclude', 'format_', 'start_date', 'end_date', 'last_n_days', 'sort', 'display_date', ),
+    'get_dry_dock_web': ('port_id', 'port_unlocode', 'shipyard_id', 'country_code', 'region_id', 'segment', 'sub_segment', 'group_by', 'exclude', 'format_', 'start_date', 'end_date', 'last_n_days', 'sort', 'display_date', ),
 
     }
 
